@@ -9,6 +9,7 @@ import tomli
 import validators
 from pydantic import (
     BaseSettings,
+    Extra,
     PostgresDsn,
     ValidationError,
     root_validator,
@@ -26,7 +27,7 @@ class FidesSettings(BaseSettings):
 
     class Config:
         # Need to allow extras because the inheriting class will have more info
-        extras = "allow"
+        extra = Extra.allow
 
         @classmethod
         def customise_sources(
@@ -173,9 +174,9 @@ class FidesConfig(FidesSettings):
     database: DatabaseSettings
     security: SecuritySettings
 
-    is_test_mode: bool = os.getenv("TESTING") == "True"
-    hot_reloading: bool = os.getenv("FIDES__HOT_RELOAD") == "True"
-    dev_mode: bool = os.getenv("FIDES__DEV_MODE") == "True"
+    is_test_mode: bool = os.getenv("TESTING", "").lower() == "true"
+    hot_reloading: bool = os.getenv("FIDES__HOT_RELOAD", "").lower() == "true"
+    dev_mode: bool = os.getenv("FIDES__DEV_MODE", "").lower() == "true"
 
     class Config:
         case_sensitive = True
